/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.4.2 (build: 2013-08-21 15:27:30 UTC)
 *  on 2013-08-21 at 21:11:59 UTC 
 */

package com.google.api.services.adexchangeseller;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.common.base.Preconditions;

/**
 * Service definition for AdExchangeSeller (v1).
 *
 * <p>
 * Gives Ad Exchange seller users access to their inventory and the ability to generate reports
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/ad-exchange/seller-rest/" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link AdExchangeSellerRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class AdExchangeSeller extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the Ad Exchange Seller API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "adexchangeseller/v1/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public AdExchangeSeller(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  AdExchangeSeller(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Adclients collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdExchangeSeller adexchangeseller = new AdExchangeSeller(...);}
   *   {@code AdExchangeSeller.Adclients.List request = adexchangeseller.adclients().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Adclients adclients() {
    return new Adclients();
  }

  /**
   * The "adclients" collection of methods.
   */
  public class Adclients {

    /**
     * List all ad clients in this Ad Exchange account.
     *
     * Create a request for the method "adclients.list".
     *
     * This request holds the parameters needed by the the adexchangeseller server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.AdClients> {

      private static final String REST_PATH = "adclients";

      /**
       * List all ad clients in this Ad Exchange account.
       *
       * Create a request for the method "adclients.list".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.AdClients.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /**
     * A continuation token, used to page through ad clients. To retrieve the next page, set this
     * parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** A continuation token, used to page through ad clients. To retrieve the next page, set this
     parameter to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * A continuation token, used to page through ad clients. To retrieve the next page, set this
     * parameter to the value of "nextPageToken" from the previous response.
     */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of ad clients to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of ad clients to include in the response, used for paging.

     [minimum: 0] [maximum: 10000]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** The maximum number of ad clients to include in the response, used for paging. */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Adunits collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdExchangeSeller adexchangeseller = new AdExchangeSeller(...);}
   *   {@code AdExchangeSeller.Adunits.List request = adexchangeseller.adunits().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Adunits adunits() {
    return new Adunits();
  }

  /**
   * The "adunits" collection of methods.
   */
  public class Adunits {

    /**
     * Gets the specified ad unit in the specified ad client.
     *
     * Create a request for the method "adunits.get".
     *
     * This request holds the parameters needed by the the adexchangeseller server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client for which to get the ad unit.
     * @param adUnitId Ad unit to retrieve.
     * @return the request
     */
    public Get get(String adClientId, String adUnitId) throws java.io.IOException {
      Get result = new Get(adClientId, adUnitId);
      initialize(result);
      return result;
    }

    public class Get extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.AdUnit> {

      private static final String REST_PATH = "adclients/{adClientId}/adunits/{adUnitId}";

      /**
       * Gets the specified ad unit in the specified ad client.
       *
       * Create a request for the method "adunits.get".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client for which to get the ad unit.
       * @param adUnitId Ad unit to retrieve.
       * @since 1.13
       */
      protected Get(String adClientId, String adUnitId) {
        super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.AdUnit.class);
        this.adClientId = Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
        this.adUnitId = Preconditions.checkNotNull(adUnitId, "Required parameter adUnitId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Ad client for which to get the ad unit. */
      @com.google.api.client.util.Key
      private String adClientId;

      /** Ad client for which to get the ad unit.
       */
      public String getAdClientId() {
        return adClientId;
      }

      /** Ad client for which to get the ad unit. */
      public Get setAdClientId(String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /** Ad unit to retrieve. */
      @com.google.api.client.util.Key
      private String adUnitId;

      /** Ad unit to retrieve.
       */
      public String getAdUnitId() {
        return adUnitId;
      }

      /** Ad unit to retrieve. */
      public Get setAdUnitId(String adUnitId) {
        this.adUnitId = adUnitId;
        return this;
      }

    }
    /**
     * List all ad units in the specified ad client for this Ad Exchange account.
     *
     * Create a request for the method "adunits.list".
     *
     * This request holds the parameters needed by the the adexchangeseller server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client for which to list ad units.
     * @return the request
     */
    public List list(String adClientId) throws java.io.IOException {
      List result = new List(adClientId);
      initialize(result);
      return result;
    }

    public class List extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.AdUnits> {

      private static final String REST_PATH = "adclients/{adClientId}/adunits";

      /**
       * List all ad units in the specified ad client for this Ad Exchange account.
       *
       * Create a request for the method "adunits.list".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client for which to list ad units.
       * @since 1.13
       */
      protected List(String adClientId) {
        super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.AdUnits.class);
        this.adClientId = Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Ad client for which to list ad units. */
      @com.google.api.client.util.Key
      private String adClientId;

      /** Ad client for which to list ad units.
       */
      public String getAdClientId() {
        return adClientId;
      }

      /** Ad client for which to list ad units. */
      public List setAdClientId(String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /** Whether to include inactive ad units. Default: true. */
      @com.google.api.client.util.Key
      private Boolean includeInactive;

      /** Whether to include inactive ad units. Default: true.
       */
      public Boolean getIncludeInactive() {
        return includeInactive;
      }

      /** Whether to include inactive ad units. Default: true. */
      public List setIncludeInactive(Boolean includeInactive) {
        this.includeInactive = includeInactive;
        return this;
      }

      /**
     * A continuation token, used to page through ad units. To retrieve the next page, set this
     * parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** A continuation token, used to page through ad units. To retrieve the next page, set this parameter
     to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * A continuation token, used to page through ad units. To retrieve the next page, set this
     * parameter to the value of "nextPageToken" from the previous response.
     */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of ad units to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of ad units to include in the response, used for paging.

     [minimum: 0] [maximum: 10000]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** The maximum number of ad units to include in the response, used for paging. */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }

    /**
     * An accessor for creating requests from the Customchannels collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdExchangeSeller adexchangeseller = new AdExchangeSeller(...);}
     *   {@code AdExchangeSeller.Customchannels.List request = adexchangeseller.customchannels().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Customchannels customchannels() {
      return new Customchannels();
    }

    /**
     * The "customchannels" collection of methods.
     */
    public class Customchannels {

      /**
       * List all custom channels which the specified ad unit belongs to.
       *
       * Create a request for the method "customchannels.list".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param adClientId Ad client which contains the ad unit.
       * @param adUnitId Ad unit for which to list custom channels.
       * @return the request
       */
      public List list(String adClientId, String adUnitId) throws java.io.IOException {
        List result = new List(adClientId, adUnitId);
        initialize(result);
        return result;
      }

      public class List extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.CustomChannels> {

        private static final String REST_PATH = "adclients/{adClientId}/adunits/{adUnitId}/customchannels";

        /**
         * List all custom channels which the specified ad unit belongs to.
         *
         * Create a request for the method "customchannels.list".
         *
         * This request holds the parameters needed by the the adexchangeseller server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param adClientId Ad client which contains the ad unit.
         * @param adUnitId Ad unit for which to list custom channels.
         * @since 1.13
         */
        protected List(String adClientId, String adUnitId) {
          super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.CustomChannels.class);
          this.adClientId = Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
          this.adUnitId = Preconditions.checkNotNull(adUnitId, "Required parameter adUnitId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** Ad client which contains the ad unit. */
        @com.google.api.client.util.Key
        private String adClientId;

        /** Ad client which contains the ad unit.
         */
        public String getAdClientId() {
          return adClientId;
        }

        /** Ad client which contains the ad unit. */
        public List setAdClientId(String adClientId) {
          this.adClientId = adClientId;
          return this;
        }

        /** Ad unit for which to list custom channels. */
        @com.google.api.client.util.Key
        private String adUnitId;

        /** Ad unit for which to list custom channels.
         */
        public String getAdUnitId() {
          return adUnitId;
        }

        /** Ad unit for which to list custom channels. */
        public List setAdUnitId(String adUnitId) {
          this.adUnitId = adUnitId;
          return this;
        }

        /**
       * A continuation token, used to page through custom channels. To retrieve the next page, set
       * this parameter to the value of "nextPageToken" from the previous response.
       */
        @com.google.api.client.util.Key
        private String pageToken;

        /** A continuation token, used to page through custom channels. To retrieve the next page, set this
       parameter to the value of "nextPageToken" from the previous response.
         */
        public String getPageToken() {
          return pageToken;
        }

        /**
       * A continuation token, used to page through custom channels. To retrieve the next page, set
       * this parameter to the value of "nextPageToken" from the previous response.
       */
        public List setPageToken(String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of custom channels to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private Long maxResults;

        /** The maximum number of custom channels to include in the response, used for paging.

       [minimum: 0] [maximum: 10000]
         */
        public Long getMaxResults() {
          return maxResults;
        }

        /** The maximum number of custom channels to include in the response, used for paging. */
        public List setMaxResults(Long maxResults) {
          this.maxResults = maxResults;
          return this;
        }

      }

    }
  }

  /**
   * An accessor for creating requests from the Customchannels collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdExchangeSeller adexchangeseller = new AdExchangeSeller(...);}
   *   {@code AdExchangeSeller.Customchannels.List request = adexchangeseller.customchannels().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Customchannels customchannels() {
    return new Customchannels();
  }

  /**
   * The "customchannels" collection of methods.
   */
  public class Customchannels {

    /**
     * Get the specified custom channel from the specified ad client.
     *
     * Create a request for the method "customchannels.get".
     *
     * This request holds the parameters needed by the the adexchangeseller server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client which contains the custom channel.
     * @param customChannelId Custom channel to retrieve.
     * @return the request
     */
    public Get get(String adClientId, String customChannelId) throws java.io.IOException {
      Get result = new Get(adClientId, customChannelId);
      initialize(result);
      return result;
    }

    public class Get extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.CustomChannel> {

      private static final String REST_PATH = "adclients/{adClientId}/customchannels/{customChannelId}";

      /**
       * Get the specified custom channel from the specified ad client.
       *
       * Create a request for the method "customchannels.get".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client which contains the custom channel.
       * @param customChannelId Custom channel to retrieve.
       * @since 1.13
       */
      protected Get(String adClientId, String customChannelId) {
        super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.CustomChannel.class);
        this.adClientId = Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
        this.customChannelId = Preconditions.checkNotNull(customChannelId, "Required parameter customChannelId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Ad client which contains the custom channel. */
      @com.google.api.client.util.Key
      private String adClientId;

      /** Ad client which contains the custom channel.
       */
      public String getAdClientId() {
        return adClientId;
      }

      /** Ad client which contains the custom channel. */
      public Get setAdClientId(String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /** Custom channel to retrieve. */
      @com.google.api.client.util.Key
      private String customChannelId;

      /** Custom channel to retrieve.
       */
      public String getCustomChannelId() {
        return customChannelId;
      }

      /** Custom channel to retrieve. */
      public Get setCustomChannelId(String customChannelId) {
        this.customChannelId = customChannelId;
        return this;
      }

    }
    /**
     * List all custom channels in the specified ad client for this Ad Exchange account.
     *
     * Create a request for the method "customchannels.list".
     *
     * This request holds the parameters needed by the the adexchangeseller server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client for which to list custom channels.
     * @return the request
     */
    public List list(String adClientId) throws java.io.IOException {
      List result = new List(adClientId);
      initialize(result);
      return result;
    }

    public class List extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.CustomChannels> {

      private static final String REST_PATH = "adclients/{adClientId}/customchannels";

      /**
       * List all custom channels in the specified ad client for this Ad Exchange account.
       *
       * Create a request for the method "customchannels.list".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client for which to list custom channels.
       * @since 1.13
       */
      protected List(String adClientId) {
        super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.CustomChannels.class);
        this.adClientId = Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Ad client for which to list custom channels. */
      @com.google.api.client.util.Key
      private String adClientId;

      /** Ad client for which to list custom channels.
       */
      public String getAdClientId() {
        return adClientId;
      }

      /** Ad client for which to list custom channels. */
      public List setAdClientId(String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /**
     * A continuation token, used to page through custom channels. To retrieve the next page, set
     * this parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** A continuation token, used to page through custom channels. To retrieve the next page, set this
     parameter to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * A continuation token, used to page through custom channels. To retrieve the next page, set
     * this parameter to the value of "nextPageToken" from the previous response.
     */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of custom channels to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of custom channels to include in the response, used for paging.

     [minimum: 0] [maximum: 10000]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** The maximum number of custom channels to include in the response, used for paging. */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }

    /**
     * An accessor for creating requests from the Adunits collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdExchangeSeller adexchangeseller = new AdExchangeSeller(...);}
     *   {@code AdExchangeSeller.Adunits.List request = adexchangeseller.adunits().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Adunits adunits() {
      return new Adunits();
    }

    /**
     * The "adunits" collection of methods.
     */
    public class Adunits {

      /**
       * List all ad units in the specified custom channel.
       *
       * Create a request for the method "adunits.list".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param adClientId Ad client which contains the custom channel.
       * @param customChannelId Custom channel for which to list ad units.
       * @return the request
       */
      public List list(String adClientId, String customChannelId) throws java.io.IOException {
        List result = new List(adClientId, customChannelId);
        initialize(result);
        return result;
      }

      public class List extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.AdUnits> {

        private static final String REST_PATH = "adclients/{adClientId}/customchannels/{customChannelId}/adunits";

        /**
         * List all ad units in the specified custom channel.
         *
         * Create a request for the method "adunits.list".
         *
         * This request holds the parameters needed by the the adexchangeseller server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param adClientId Ad client which contains the custom channel.
         * @param customChannelId Custom channel for which to list ad units.
         * @since 1.13
         */
        protected List(String adClientId, String customChannelId) {
          super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.AdUnits.class);
          this.adClientId = Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
          this.customChannelId = Preconditions.checkNotNull(customChannelId, "Required parameter customChannelId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** Ad client which contains the custom channel. */
        @com.google.api.client.util.Key
        private String adClientId;

        /** Ad client which contains the custom channel.
         */
        public String getAdClientId() {
          return adClientId;
        }

        /** Ad client which contains the custom channel. */
        public List setAdClientId(String adClientId) {
          this.adClientId = adClientId;
          return this;
        }

        /** Custom channel for which to list ad units. */
        @com.google.api.client.util.Key
        private String customChannelId;

        /** Custom channel for which to list ad units.
         */
        public String getCustomChannelId() {
          return customChannelId;
        }

        /** Custom channel for which to list ad units. */
        public List setCustomChannelId(String customChannelId) {
          this.customChannelId = customChannelId;
          return this;
        }

        /** Whether to include inactive ad units. Default: true. */
        @com.google.api.client.util.Key
        private Boolean includeInactive;

        /** Whether to include inactive ad units. Default: true.
         */
        public Boolean getIncludeInactive() {
          return includeInactive;
        }

        /** Whether to include inactive ad units. Default: true. */
        public List setIncludeInactive(Boolean includeInactive) {
          this.includeInactive = includeInactive;
          return this;
        }

        /**
       * A continuation token, used to page through ad units. To retrieve the next page, set this
       * parameter to the value of "nextPageToken" from the previous response.
       */
        @com.google.api.client.util.Key
        private String pageToken;

        /** A continuation token, used to page through ad units. To retrieve the next page, set this parameter
       to the value of "nextPageToken" from the previous response.
         */
        public String getPageToken() {
          return pageToken;
        }

        /**
       * A continuation token, used to page through ad units. To retrieve the next page, set this
       * parameter to the value of "nextPageToken" from the previous response.
       */
        public List setPageToken(String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of ad units to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private Long maxResults;

        /** The maximum number of ad units to include in the response, used for paging.

       [minimum: 0] [maximum: 10000]
         */
        public Long getMaxResults() {
          return maxResults;
        }

        /** The maximum number of ad units to include in the response, used for paging. */
        public List setMaxResults(Long maxResults) {
          this.maxResults = maxResults;
          return this;
        }

      }

    }
  }

  /**
   * An accessor for creating requests from the Reports collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdExchangeSeller adexchangeseller = new AdExchangeSeller(...);}
   *   {@code AdExchangeSeller.Reports.List request = adexchangeseller.reports().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Reports reports() {
    return new Reports();
  }

  /**
   * The "reports" collection of methods.
   */
  public class Reports {

    /**
     * Generate an Ad Exchange report based on the report request sent in the query parameters. Returns
     * the result as JSON; to retrieve output in CSV format specify "alt=csv" as a query parameter.
     *
     * Create a request for the method "reports.generate".
     *
     * This request holds the parameters needed by the the adexchangeseller server.  After setting any
     * optional parameters, call the {@link Generate#execute()} method to invoke the remote operation.
     *
     * @param startDate Start of the date range to report on in "YYYY-MM-DD" format, inclusive.
     * @param endDate End of the date range to report on in "YYYY-MM-DD" format, inclusive.
     * @return the request
     */
    public Generate generate(String startDate, String endDate) throws java.io.IOException {
      Generate result = new Generate(startDate, endDate);
      initialize(result);
      return result;
    }

    public class Generate extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.Report> {

      private static final String REST_PATH = "reports";

      private final java.util.regex.Pattern STARTDATE_PATTERN =
          java.util.regex.Pattern.compile("\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");

      private final java.util.regex.Pattern ENDDATE_PATTERN =
          java.util.regex.Pattern.compile("\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");

      private final java.util.regex.Pattern SORT_PATTERN =
          java.util.regex.Pattern.compile("(\\+|-)?[a-zA-Z_]+");

      private final java.util.regex.Pattern LOCALE_PATTERN =
          java.util.regex.Pattern.compile("[a-zA-Z_]+");

      private final java.util.regex.Pattern METRIC_PATTERN =
          java.util.regex.Pattern.compile("[a-zA-Z_]+");

      private final java.util.regex.Pattern FILTER_PATTERN =
          java.util.regex.Pattern.compile("[a-zA-Z_]+(==|=@).+");

      private final java.util.regex.Pattern DIMENSION_PATTERN =
          java.util.regex.Pattern.compile("[a-zA-Z_]+");

      /**
       * Generate an Ad Exchange report based on the report request sent in the query parameters.
       * Returns the result as JSON; to retrieve output in CSV format specify "alt=csv" as a query
       * parameter.
       *
       * Create a request for the method "reports.generate".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link Generate#execute()} method to invoke the remote operation.
       * <p> {@link Generate#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param startDate Start of the date range to report on in "YYYY-MM-DD" format, inclusive.
       * @param endDate End of the date range to report on in "YYYY-MM-DD" format, inclusive.
       * @since 1.13
       */
      protected Generate(String startDate, String endDate) {
        super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.Report.class);
        this.startDate = Preconditions.checkNotNull(startDate, "Required parameter startDate must be specified.");
        if (!getSuppressPatternChecks()) {
          Preconditions.checkArgument(STARTDATE_PATTERN.matcher(startDate).matches(),
              "Parameter startDate must conform to the pattern " +
              "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
        }
        this.endDate = Preconditions.checkNotNull(endDate, "Required parameter endDate must be specified.");
        if (!getSuppressPatternChecks()) {
          Preconditions.checkArgument(ENDDATE_PATTERN.matcher(endDate).matches(),
              "Parameter endDate must conform to the pattern " +
              "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
        }
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Generate setAlt(String alt) {
        return (Generate) super.setAlt(alt);
      }

      @Override
      public Generate setFields(String fields) {
        return (Generate) super.setFields(fields);
      }

      @Override
      public Generate setKey(String key) {
        return (Generate) super.setKey(key);
      }

      @Override
      public Generate setOauthToken(String oauthToken) {
        return (Generate) super.setOauthToken(oauthToken);
      }

      @Override
      public Generate setPrettyPrint(Boolean prettyPrint) {
        return (Generate) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Generate setQuotaUser(String quotaUser) {
        return (Generate) super.setQuotaUser(quotaUser);
      }

      @Override
      public Generate setUserIp(String userIp) {
        return (Generate) super.setUserIp(userIp);
      }

      /** Start of the date range to report on in "YYYY-MM-DD" format, inclusive. */
      @com.google.api.client.util.Key
      private String startDate;

      /** Start of the date range to report on in "YYYY-MM-DD" format, inclusive.
       */
      public String getStartDate() {
        return startDate;
      }

      /** Start of the date range to report on in "YYYY-MM-DD" format, inclusive. */
      public Generate setStartDate(String startDate) {
        if (!getSuppressPatternChecks()) {
          Preconditions.checkArgument(STARTDATE_PATTERN.matcher(startDate).matches(),
              "Parameter startDate must conform to the pattern " +
              "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
        }
        this.startDate = startDate;
        return this;
      }

      /** End of the date range to report on in "YYYY-MM-DD" format, inclusive. */
      @com.google.api.client.util.Key
      private String endDate;

      /** End of the date range to report on in "YYYY-MM-DD" format, inclusive.
       */
      public String getEndDate() {
        return endDate;
      }

      /** End of the date range to report on in "YYYY-MM-DD" format, inclusive. */
      public Generate setEndDate(String endDate) {
        if (!getSuppressPatternChecks()) {
          Preconditions.checkArgument(ENDDATE_PATTERN.matcher(endDate).matches(),
              "Parameter endDate must conform to the pattern " +
              "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
        }
        this.endDate = endDate;
        return this;
      }

      /**
     * The name of a dimension or metric to sort the resulting report on, optionally prefixed with
     * "+" to sort ascending or "-" to sort descending. If no prefix is specified, the column is
     * sorted ascending.
     */
      @com.google.api.client.util.Key
      private java.util.List<String> sort;

      /** The name of a dimension or metric to sort the resulting report on, optionally prefixed with "+" to
     sort ascending or "-" to sort descending. If no prefix is specified, the column is sorted
     ascending.
       */
      public java.util.List<String> getSort() {
        return sort;
      }

      /**
     * The name of a dimension or metric to sort the resulting report on, optionally prefixed with
     * "+" to sort ascending or "-" to sort descending. If no prefix is specified, the column is
     * sorted ascending.
     */
      public Generate setSort(java.util.List<String> sort) {
        if (!getSuppressPatternChecks()) {
          for (String sortElem : sort) {
            Preconditions.checkArgument(SORT_PATTERN.matcher(sortElem).matches(),
                "Parameter sort elements must conform to the pattern " +
                "(\\+|-)?[a-zA-Z_]+");
          }
        }
        this.sort = sort;
        return this;
      }

      /**
     * Optional locale to use for translating report output to a local language. Defaults to "en_US"
     * if not specified.
     */
      @com.google.api.client.util.Key
      private String locale;

      /** Optional locale to use for translating report output to a local language. Defaults to "en_US" if
     not specified.
       */
      public String getLocale() {
        return locale;
      }

      /**
     * Optional locale to use for translating report output to a local language. Defaults to "en_US"
     * if not specified.
     */
      public Generate setLocale(String locale) {
        if (!getSuppressPatternChecks()) {
          Preconditions.checkArgument(LOCALE_PATTERN.matcher(locale).matches(),
              "Parameter locale must conform to the pattern " +
              "[a-zA-Z_]+");
        }
        this.locale = locale;
        return this;
      }

      /** Numeric columns to include in the report. */
      @com.google.api.client.util.Key
      private java.util.List<String> metric;

      /** Numeric columns to include in the report.
       */
      public java.util.List<String> getMetric() {
        return metric;
      }

      /** Numeric columns to include in the report. */
      public Generate setMetric(java.util.List<String> metric) {
        if (!getSuppressPatternChecks()) {
          for (String metricElem : metric) {
            Preconditions.checkArgument(METRIC_PATTERN.matcher(metricElem).matches(),
                "Parameter metric elements must conform to the pattern " +
                "[a-zA-Z_]+");
          }
        }
        this.metric = metric;
        return this;
      }

      /** The maximum number of rows of report data to return. */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of rows of report data to return.

     [minimum: 0] [maximum: 50000]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** The maximum number of rows of report data to return. */
      public Generate setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** Filters to be run on the report. */
      @com.google.api.client.util.Key
      private java.util.List<String> filter;

      /** Filters to be run on the report.
       */
      public java.util.List<String> getFilter() {
        return filter;
      }

      /** Filters to be run on the report. */
      public Generate setFilter(java.util.List<String> filter) {
        if (!getSuppressPatternChecks()) {
          for (String filterElem : filter) {
            Preconditions.checkArgument(FILTER_PATTERN.matcher(filterElem).matches(),
                "Parameter filter elements must conform to the pattern " +
                "[a-zA-Z_]+(==|=@).+");
          }
        }
        this.filter = filter;
        return this;
      }

      /** Index of the first row of report data to return. */
      @com.google.api.client.util.Key
      private Long startIndex;

      /** Index of the first row of report data to return.

     [minimum: 0] [maximum: 5000]
       */
      public Long getStartIndex() {
        return startIndex;
      }

      /** Index of the first row of report data to return. */
      public Generate setStartIndex(Long startIndex) {
        this.startIndex = startIndex;
        return this;
      }

      /** Dimensions to base the report on. */
      @com.google.api.client.util.Key
      private java.util.List<String> dimension;

      /** Dimensions to base the report on.
       */
      public java.util.List<String> getDimension() {
        return dimension;
      }

      /** Dimensions to base the report on. */
      public Generate setDimension(java.util.List<String> dimension) {
        if (!getSuppressPatternChecks()) {
          for (String dimensionElem : dimension) {
            Preconditions.checkArgument(DIMENSION_PATTERN.matcher(dimensionElem).matches(),
                "Parameter dimension elements must conform to the pattern " +
                "[a-zA-Z_]+");
          }
        }
        this.dimension = dimension;
        return this;
      }

    }

    /**
     * An accessor for creating requests from the Saved collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdExchangeSeller adexchangeseller = new AdExchangeSeller(...);}
     *   {@code AdExchangeSeller.Saved.List request = adexchangeseller.saved().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Saved saved() {
      return new Saved();
    }

    /**
     * The "saved" collection of methods.
     */
    public class Saved {

      /**
       * Generate an Ad Exchange report based on the saved report ID sent in the query parameters.
       *
       * Create a request for the method "saved.generate".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link Generate#execute()} method to invoke the remote operation.
       *
       * @param savedReportId The saved report to retrieve.
       * @return the request
       */
      public Generate generate(String savedReportId) throws java.io.IOException {
        Generate result = new Generate(savedReportId);
        initialize(result);
        return result;
      }

      public class Generate extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.Report> {

        private static final String REST_PATH = "reports/{savedReportId}";

        private final java.util.regex.Pattern LOCALE_PATTERN =
            java.util.regex.Pattern.compile("[a-zA-Z_]+");

        /**
         * Generate an Ad Exchange report based on the saved report ID sent in the query parameters.
         *
         * Create a request for the method "saved.generate".
         *
         * This request holds the parameters needed by the the adexchangeseller server.  After setting any
         * optional parameters, call the {@link Generate#execute()} method to invoke the remote operation.
         * <p> {@link Generate#initialize(AbstractGoogleClientRequest)} must be called to initialize this
         * instance immediately after invoking the constructor. </p>
         *
         * @param savedReportId The saved report to retrieve.
         * @since 1.13
         */
        protected Generate(String savedReportId) {
          super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.Report.class);
          this.savedReportId = Preconditions.checkNotNull(savedReportId, "Required parameter savedReportId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Generate setAlt(String alt) {
          return (Generate) super.setAlt(alt);
        }

        @Override
        public Generate setFields(String fields) {
          return (Generate) super.setFields(fields);
        }

        @Override
        public Generate setKey(String key) {
          return (Generate) super.setKey(key);
        }

        @Override
        public Generate setOauthToken(String oauthToken) {
          return (Generate) super.setOauthToken(oauthToken);
        }

        @Override
        public Generate setPrettyPrint(Boolean prettyPrint) {
          return (Generate) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Generate setQuotaUser(String quotaUser) {
          return (Generate) super.setQuotaUser(quotaUser);
        }

        @Override
        public Generate setUserIp(String userIp) {
          return (Generate) super.setUserIp(userIp);
        }

        /** The saved report to retrieve. */
        @com.google.api.client.util.Key
        private String savedReportId;

        /** The saved report to retrieve.
         */
        public String getSavedReportId() {
          return savedReportId;
        }

        /** The saved report to retrieve. */
        public Generate setSavedReportId(String savedReportId) {
          this.savedReportId = savedReportId;
          return this;
        }

        /**
       * Optional locale to use for translating report output to a local language. Defaults to
       * "en_US" if not specified.
       */
        @com.google.api.client.util.Key
        private String locale;

        /** Optional locale to use for translating report output to a local language. Defaults to "en_US" if
       not specified.
         */
        public String getLocale() {
          return locale;
        }

        /**
       * Optional locale to use for translating report output to a local language. Defaults to
       * "en_US" if not specified.
       */
        public Generate setLocale(String locale) {
          if (!getSuppressPatternChecks()) {
            Preconditions.checkArgument(LOCALE_PATTERN.matcher(locale).matches(),
                "Parameter locale must conform to the pattern " +
                "[a-zA-Z_]+");
          }
          this.locale = locale;
          return this;
        }

        /** Index of the first row of report data to return. */
        @com.google.api.client.util.Key
        private Integer startIndex;

        /** Index of the first row of report data to return.

       [minimum: 0] [maximum: 5000]
         */
        public Integer getStartIndex() {
          return startIndex;
        }

        /** Index of the first row of report data to return. */
        public Generate setStartIndex(Integer startIndex) {
          this.startIndex = startIndex;
          return this;
        }

        /** The maximum number of rows of report data to return. */
        @com.google.api.client.util.Key
        private Integer maxResults;

        /** The maximum number of rows of report data to return.

       [minimum: 0] [maximum: 50000]
         */
        public Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of rows of report data to return. */
        public Generate setMaxResults(Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

      }
      /**
       * List all saved reports in this Ad Exchange account.
       *
       * Create a request for the method "saved.list".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @return the request
       */
      public List list() throws java.io.IOException {
        List result = new List();
        initialize(result);
        return result;
      }

      public class List extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.SavedReports> {

        private static final String REST_PATH = "reports/saved";

        /**
         * List all saved reports in this Ad Exchange account.
         *
         * Create a request for the method "saved.list".
         *
         * This request holds the parameters needed by the the adexchangeseller server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @since 1.13
         */
        protected List() {
          super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.SavedReports.class);
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /**
       * A continuation token, used to page through saved reports. To retrieve the next page, set
       * this parameter to the value of "nextPageToken" from the previous response.
       */
        @com.google.api.client.util.Key
        private String pageToken;

        /** A continuation token, used to page through saved reports. To retrieve the next page, set this
       parameter to the value of "nextPageToken" from the previous response.
         */
        public String getPageToken() {
          return pageToken;
        }

        /**
       * A continuation token, used to page through saved reports. To retrieve the next page, set
       * this parameter to the value of "nextPageToken" from the previous response.
       */
        public List setPageToken(String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of saved reports to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private Integer maxResults;

        /** The maximum number of saved reports to include in the response, used for paging.

       [minimum: 0] [maximum: 100]
         */
        public Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of saved reports to include in the response, used for paging. */
        public List setMaxResults(Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

      }

    }
  }

  /**
   * An accessor for creating requests from the Urlchannels collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdExchangeSeller adexchangeseller = new AdExchangeSeller(...);}
   *   {@code AdExchangeSeller.Urlchannels.List request = adexchangeseller.urlchannels().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Urlchannels urlchannels() {
    return new Urlchannels();
  }

  /**
   * The "urlchannels" collection of methods.
   */
  public class Urlchannels {

    /**
     * List all URL channels in the specified ad client for this Ad Exchange account.
     *
     * Create a request for the method "urlchannels.list".
     *
     * This request holds the parameters needed by the the adexchangeseller server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client for which to list URL channels.
     * @return the request
     */
    public List list(String adClientId) throws java.io.IOException {
      List result = new List(adClientId);
      initialize(result);
      return result;
    }

    public class List extends AdExchangeSellerRequest<com.google.api.services.adexchangeseller.model.UrlChannels> {

      private static final String REST_PATH = "adclients/{adClientId}/urlchannels";

      /**
       * List all URL channels in the specified ad client for this Ad Exchange account.
       *
       * Create a request for the method "urlchannels.list".
       *
       * This request holds the parameters needed by the the adexchangeseller server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client for which to list URL channels.
       * @since 1.13
       */
      protected List(String adClientId) {
        super(AdExchangeSeller.this, "GET", REST_PATH, null, com.google.api.services.adexchangeseller.model.UrlChannels.class);
        this.adClientId = Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Ad client for which to list URL channels. */
      @com.google.api.client.util.Key
      private String adClientId;

      /** Ad client for which to list URL channels.
       */
      public String getAdClientId() {
        return adClientId;
      }

      /** Ad client for which to list URL channels. */
      public List setAdClientId(String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /**
     * A continuation token, used to page through URL channels. To retrieve the next page, set this
     * parameter to the value of "nextPageToken" from the previous response.
     */
      @com.google.api.client.util.Key
      private String pageToken;

      /** A continuation token, used to page through URL channels. To retrieve the next page, set this
     parameter to the value of "nextPageToken" from the previous response.
       */
      public String getPageToken() {
        return pageToken;
      }

      /**
     * A continuation token, used to page through URL channels. To retrieve the next page, set this
     * parameter to the value of "nextPageToken" from the previous response.
     */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of URL channels to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of URL channels to include in the response, used for paging.

     [minimum: 0] [maximum: 10000]
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** The maximum number of URL channels to include in the response, used for paging. */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }

  }

  /**
   * Builder for {@link AdExchangeSeller}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link AdExchangeSeller}. */
    @Override
    public AdExchangeSeller build() {
      return new AdExchangeSeller(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link AdExchangeSellerRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setAdExchangeSellerRequestInitializer(
        AdExchangeSellerRequestInitializer adexchangesellerRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(adexchangesellerRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
