/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.adexchangeseller.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for CustomChannel.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ad Exchange Seller API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class CustomChannel extends GenericJson {

  /**
   * Code of this custom channel, not necessarily unique across ad clients.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String code;

  /**
   * Unique identifier of this custom channel. This should be considered an opaque identifier; it is
   * not safe to rely on it being in any particular format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * Kind of resource this is, in this case adexchangeseller#customChannel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Name of this custom channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The targeting information of this custom channel, if activated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private TargetingInfo targetingInfo;

  /**
   * Code of this custom channel, not necessarily unique across ad clients.
   * The value returned may be {@code null}.
   */
  public String getCode() {
    return code;
  }

  /**
   * Code of this custom channel, not necessarily unique across ad clients.
   * The value set may be {@code null}.
   */
  public CustomChannel setCode(String code) {
    this.code = code;
    return this;
  }

  /**
   * Unique identifier of this custom channel. This should be considered an opaque identifier; it is
   * not safe to rely on it being in any particular format.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Unique identifier of this custom channel. This should be considered an opaque identifier; it is
   * not safe to rely on it being in any particular format.
   * The value set may be {@code null}.
   */
  public CustomChannel setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * Kind of resource this is, in this case adexchangeseller#customChannel.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Kind of resource this is, in this case adexchangeseller#customChannel.
   * The value set may be {@code null}.
   */
  public CustomChannel setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Name of this custom channel.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * Name of this custom channel.
   * The value set may be {@code null}.
   */
  public CustomChannel setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * The targeting information of this custom channel, if activated.
   * The value returned may be {@code null}.
   */
  public TargetingInfo getTargetingInfo() {
    return targetingInfo;
  }

  /**
   * The targeting information of this custom channel, if activated.
   * The value set may be {@code null}.
   */
  public CustomChannel setTargetingInfo(TargetingInfo targetingInfo) {
    this.targetingInfo = targetingInfo;
    return this;
  }

  /**
   * The targeting information of this custom channel, if activated.
   */
  public static final class TargetingInfo extends GenericJson {

    /**
     * The name used to describe this channel externally.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String adsAppearOn;

    /**
     * The external description of the channel.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String description;

    /**
     * The locations in which ads appear. (Only valid for content and mobile content ads). Acceptable
     * values for content ads are: TOP_LEFT, TOP_CENTER, TOP_RIGHT, MIDDLE_LEFT, MIDDLE_CENTER,
     * MIDDLE_RIGHT, BOTTOM_LEFT, BOTTOM_CENTER, BOTTOM_RIGHT, MULTIPLE_LOCATIONS. Acceptable values
     * for mobile content ads are: TOP, MIDDLE, BOTTOM, MULTIPLE_LOCATIONS.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String location;

    /**
     * The language of the sites ads will be displayed on.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String siteLanguage;

    /**
     * The name used to describe this channel externally.
     * The value returned may be {@code null}.
     */
    public String getAdsAppearOn() {
      return adsAppearOn;
    }

    /**
     * The name used to describe this channel externally.
     * The value set may be {@code null}.
     */
    public TargetingInfo setAdsAppearOn(String adsAppearOn) {
      this.adsAppearOn = adsAppearOn;
      return this;
    }

    /**
     * The external description of the channel.
     * The value returned may be {@code null}.
     */
    public String getDescription() {
      return description;
    }

    /**
     * The external description of the channel.
     * The value set may be {@code null}.
     */
    public TargetingInfo setDescription(String description) {
      this.description = description;
      return this;
    }

    /**
     * The locations in which ads appear. (Only valid for content and mobile content ads). Acceptable
     * values for content ads are: TOP_LEFT, TOP_CENTER, TOP_RIGHT, MIDDLE_LEFT, MIDDLE_CENTER,
     * MIDDLE_RIGHT, BOTTOM_LEFT, BOTTOM_CENTER, BOTTOM_RIGHT, MULTIPLE_LOCATIONS. Acceptable values
     * for mobile content ads are: TOP, MIDDLE, BOTTOM, MULTIPLE_LOCATIONS.
     * The value returned may be {@code null}.
     */
    public String getLocation() {
      return location;
    }

    /**
     * The locations in which ads appear. (Only valid for content and mobile content ads). Acceptable
     * values for content ads are: TOP_LEFT, TOP_CENTER, TOP_RIGHT, MIDDLE_LEFT, MIDDLE_CENTER,
     * MIDDLE_RIGHT, BOTTOM_LEFT, BOTTOM_CENTER, BOTTOM_RIGHT, MULTIPLE_LOCATIONS. Acceptable values
     * for mobile content ads are: TOP, MIDDLE, BOTTOM, MULTIPLE_LOCATIONS.
     * The value set may be {@code null}.
     */
    public TargetingInfo setLocation(String location) {
      this.location = location;
      return this;
    }

    /**
     * The language of the sites ads will be displayed on.
     * The value returned may be {@code null}.
     */
    public String getSiteLanguage() {
      return siteLanguage;
    }

    /**
     * The language of the sites ads will be displayed on.
     * The value set may be {@code null}.
     */
    public TargetingInfo setSiteLanguage(String siteLanguage) {
      this.siteLanguage = siteLanguage;
      return this;
    }

  }
}
