/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.adexchangeseller.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Model definition for Report.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ad Exchange Seller API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Report extends GenericJson {

  /**
   * The averages of the report. This is the same length as any other row in the report; cells
   * corresponding to dimension columns are empty.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> averages;

  /**
   * The header information of the columns requested in the report. This is a list of headers; one
   * for each dimension in the request, followed by one for each metric in the request.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Headers> headers;

  static {
    // hack to force ProGuard to consider Headers used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Headers.class);
  }

  /**
   * Kind this is, in this case adexchangeseller#report.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The output rows of the report. Each row is a list of cells; one for each dimension in the
   * request, followed by one for each metric in the request. The dimension cells contain strings,
   * and the metric cells contain numbers.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<java.util.List<String>> rows;

  /**
   * The total number of rows matched by the report request. Fewer rows may be returned in the
   * response due to being limited by the row count requested or the report row limit.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long totalMatchedRows;

  /**
   * The totals of the report. This is the same length as any other row in the report; cells
   * corresponding to dimension columns are empty.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> totals;

  /**
   * Any warnings associated with generation of the report.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> warnings;

  /**
   * The averages of the report. This is the same length as any other row in the report; cells
   * corresponding to dimension columns are empty.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getAverages() {
    return averages;
  }

  /**
   * The averages of the report. This is the same length as any other row in the report; cells
   * corresponding to dimension columns are empty.
   * The value set may be {@code null}.
   */
  public Report setAverages(java.util.List<String> averages) {
    this.averages = averages;
    return this;
  }

  /**
   * The header information of the columns requested in the report. This is a list of headers; one
   * for each dimension in the request, followed by one for each metric in the request.
   * The value returned may be {@code null}.
   */
  public java.util.List<Headers> getHeaders() {
    return headers;
  }

  /**
   * The header information of the columns requested in the report. This is a list of headers; one
   * for each dimension in the request, followed by one for each metric in the request.
   * The value set may be {@code null}.
   */
  public Report setHeaders(java.util.List<Headers> headers) {
    this.headers = headers;
    return this;
  }

  /**
   * Kind this is, in this case adexchangeseller#report.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Kind this is, in this case adexchangeseller#report.
   * The value set may be {@code null}.
   */
  public Report setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The output rows of the report. Each row is a list of cells; one for each dimension in the
   * request, followed by one for each metric in the request. The dimension cells contain strings,
   * and the metric cells contain numbers.
   * The value returned may be {@code null}.
   */
  public java.util.List<java.util.List<String>> getRows() {
    return rows;
  }

  /**
   * The output rows of the report. Each row is a list of cells; one for each dimension in the
   * request, followed by one for each metric in the request. The dimension cells contain strings,
   * and the metric cells contain numbers.
   * The value set may be {@code null}.
   */
  public Report setRows(java.util.List<java.util.List<String>> rows) {
    this.rows = rows;
    return this;
  }

  /**
   * The total number of rows matched by the report request. Fewer rows may be returned in the
   * response due to being limited by the row count requested or the report row limit.
   * The value returned may be {@code null}.
   */
  public Long getTotalMatchedRows() {
    return totalMatchedRows;
  }

  /**
   * The total number of rows matched by the report request. Fewer rows may be returned in the
   * response due to being limited by the row count requested or the report row limit.
   * The value set may be {@code null}.
   */
  public Report setTotalMatchedRows(Long totalMatchedRows) {
    this.totalMatchedRows = totalMatchedRows;
    return this;
  }

  /**
   * The totals of the report. This is the same length as any other row in the report; cells
   * corresponding to dimension columns are empty.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getTotals() {
    return totals;
  }

  /**
   * The totals of the report. This is the same length as any other row in the report; cells
   * corresponding to dimension columns are empty.
   * The value set may be {@code null}.
   */
  public Report setTotals(java.util.List<String> totals) {
    this.totals = totals;
    return this;
  }

  /**
   * Any warnings associated with generation of the report.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getWarnings() {
    return warnings;
  }

  /**
   * Any warnings associated with generation of the report.
   * The value set may be {@code null}.
   */
  public Report setWarnings(java.util.List<String> warnings) {
    this.warnings = warnings;
    return this;
  }

  /**
   * Model definition for ReportHeaders.
   */
  public static final class Headers extends GenericJson {

    /**
     * The currency of this column. Only present if the header type is METRIC_CURRENCY.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String currency;

    /**
     * The name of the header.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String name;

    /**
     * The type of the header; one of DIMENSION, METRIC_TALLY, METRIC_RATIO, or METRIC_CURRENCY.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String type;

    /**
     * The currency of this column. Only present if the header type is METRIC_CURRENCY.
     * The value returned may be {@code null}.
     */
    public String getCurrency() {
      return currency;
    }

    /**
     * The currency of this column. Only present if the header type is METRIC_CURRENCY.
     * The value set may be {@code null}.
     */
    public Headers setCurrency(String currency) {
      this.currency = currency;
      return this;
    }

    /**
     * The name of the header.
     * The value returned may be {@code null}.
     */
    public String getName() {
      return name;
    }

    /**
     * The name of the header.
     * The value set may be {@code null}.
     */
    public Headers setName(String name) {
      this.name = name;
      return this;
    }

    /**
     * The type of the header; one of DIMENSION, METRIC_TALLY, METRIC_RATIO, or METRIC_CURRENCY.
     * The value returned may be {@code null}.
     */
    public String getType() {
      return type;
    }

    /**
     * The type of the header; one of DIMENSION, METRIC_TALLY, METRIC_RATIO, or METRIC_CURRENCY.
     * The value set may be {@code null}.
     */
    public Headers setType(String type) {
      this.type = type;
      return this;
    }

  }

}
